#
# spec file for package mpv
#
# Copyright (c) 2015 Packman Team <packman@links2linux.de>
# Copyright (c) 2012 Jiri Slaby <jslaby@suse.de>
# Copyright (c) 2011-2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define _waf_ver 1.8.8
%define lname   libmpv1
Name:           mpv
Version:        0.9.0
Release:        1.1
Summary:        Advanced general-purpose multimedia player
# waf is licensed with BSD-3-Clause but does not go to the package.
License:        GPL-2.0+
Group:          Productivity/Multimedia/Video/Players
Url:            http://mpv.io/
Source:         http://github.com/mpv-player/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        http://ftp.waf.io/pub/release/waf-%{_waf_ver}
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmng-devel
BuildRequires:  linux-kernel-headers
BuildRequires:  lirc-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  pkg-config
# TODO: replace with python3-docutils when they are fixed.
BuildRequires:  python-docutils
BuildRequires:  python3
BuildRequires:  update-desktop-files
BuildRequires:  yasm
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(caca)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(dvdnav)
BuildRequires:  pkgconfig(dvdread)
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libbluray)
BuildRequires:  pkgconfig(libbs2b)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_cdda)
BuildRequires:  pkgconfig(libcdio_paranoia)
BuildRequires:  pkgconfig(libiso9660)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libudf)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(smbclient)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
# Used via LUA scripts
Recommends:     youtube-dl
%if 0%{?suse_version} >= 1320
BuildRequires:  pkgconfig(libass) >= 0.12.1
%endif
# PDF manual.
# JIT for lua.
%if 0%{?suse_version} > 1310
BuildRequires:  python-rst2pdf
BuildRequires:  pkgconfig(luajit)
%endif
%if 0%{?suse_version} > 1230
%if 0%{?suse_version} != 1315
# Wayland and libguess.
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(libguess)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(xkbcommon)
%endif
%endif

%description
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

%package devel
Summary:        A library to link together with mpv player
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

This package contains all the development files.

%package -n %{lname}
Summary:        A library to link together with mpv player
Group:          Development/Libraries/C and C++

%description -n %{lname}
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

This package contains a library that can other apps use to utilize the mpv
features.

%prep
%setup -q

# As we downloaded specific waf version we need to put and prepare it in place.
cp -f %{SOURCE1} waf
chmod a+x waf

# I hate UNKNOWN so lets put decent info there.
MODIFIED="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="$(date -d "$MODIFIED" "+%%b %%e %%Y")"
sed -i "s|UNKNOWN|$DATE|g;s|VERSION|\"%{version}\"|g" common/version.c

%build
# SDL: disable as it is pointless to have on Linux, it is Windows/OS X fallback.
myopts="--disable-sdl1 --disable-sdl2"
# We don't want to rebuild all the time.
myopts+=" --disable-build-date"
# Debug just adds -g and we do that over optflags anyway.
myopts+=" --disable-debug"
export CCFLAGS="%{optflags}"
./waf configure \
  --prefix="%{_prefix}"              \
  --bindir="%{_bindir}"              \
  --mandir="%{_mandir}"              \
  --libdir="%{_libdir}"              \
  --docdir="%{_docdir}/%{name}"      \
  --confdir="%{_sysconfdir}/%{name}" \
%if 0%{?suse_version} < 1320
  --disable-libass                   \
%endif
  --enable-openal                    \
  --enable-cdda                      \
  --enable-libmpv-shared             \
  ${myopts}

./waf build --verbose %{?_smp_mflags}

%install
./waf --destdir=%{buildroot} install

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc Copyright LICENSE README.md etc/example.conf etc/input.conf
%dir %{_sysconfdir}/%{name}/
%config %{_sysconfdir}/%{name}/encoding-profiles.conf
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_mandir}/man?/%{name}.?%{?ext_man}

%files -n %{lname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sat Apr 25 2015 sor.alexei@meowr.ru
- Update to 0.9.0:
  * For detailed changelog see:
    https://github.com/mpv-player/mpv/releases/tag/v0.9.0
- Bump waf to 1.8.8.
- Regenerate icon theme cache after installing this package.
* Sat Mar 21 2015 scarabeus@opensuse.org
- Version bump to 0.8.3:
  * Docu updates
  * Various small tweaks
  * VAAPI now deinterlaces videos correctly
  * Smb now uses cache
- Bump waf to latest 1.8.7
* Sun Mar  1 2015 scarabeus@opensuse.org
- Put back the date info for the UNKNOWN string, I wrongly thought
  it was hardcoded to release date
* Fri Feb 27 2015 scarabeus@opensuse.org
- Version bump to 0.8.2:
  * Various bugfixes
  * For detailed changelog see:
    https://github.com/mpv-player/mpv/releases/tag/v0.8.2
- Remove conditional for 11.4 as we DONT build for it anyway.
- Fix build on factory again
- Add dep for wayland-egl enablement
- Drop the date setting content, it now is by upstream hardcoded
  to release day, which is fine
* Tue Feb 17 2015 aloisio@gmx.com
- Update to version 0.8.0:
  Changes that may break users' config files have been annotated
  with a (!).
  * (!) vo_opengl_old has been removed. OpenGL rendering now
    requires hardware that can do at least OpenGL 2.1, the oldest
    version supported by vo_opengl.
  * (!) vf_pp has been removed. A version of it can still be
    accessed through lavfilter (e.g. --vf=lavfi=[pp...]), but it
    receives no QP information. Also, vf_dlopen no longer passes
    QP information to its loaded plugin either (it's always 0).
  * (!) vf_softpulldown, vf_swapuv, vf_phase, vf_divtc and vf_ilpack
    have all been removed. Ports or alternative versions of these
    filters are available through libavfilter (vf_lavfi).
  * vf_pullup and vf_noise now are simply wrappers to their libavfilter
    equivalents. Both are only currently available on FFmpeg (not Libav).
  * (!) ao_portaudio has been removed. There is good support for the
    native audio drivers of all major desktop platforms, as well as
    ao_sdl and ao_openal as fallbacks.
  * (!) vo_opengl's lscale suboption has been renamed to scale;
    lradius is now scale-radius, lparam1 and lparam2 are now respectively
    scale-param1 and scale-param2; lscale-down is now scale-down.
    The cscale suboption remains as is.
  * (!) Several of the vo_opengl radius-preset aliases supported by
    scale have been removed; use scale-radius to set if needed. For
    example, use --vo=opengl:scale=lanczos:scale-radius=2 instead
    of scale=lanczos2. The default radius is recommended for most filters.
  * (!) vo_opengl no longer supports the stereo suboption. The anaglyph
    effect can be reproduced with the stereo3d filter. The quadbuffer
    support, which requires expensive specialized hardware to begin with,
    is removed.
  * (!) The approx-gamma suboption to vo_opengl has been removed.
    The BT.1886 specification says that it's actually how it's supposed
    to be done so it is now the default when srgb or icc-profile are enabled.
    This does not include BT.1886's gamma drop.
  * (!) The no-scale-sep and indirect suboptions to vo_opengl have been
    removed. These are now autodetected and enabled whenever they would
    have benefit.
  * (!) The --lua and --lua-opts parameters / options are now called
  - -script and --script-opts, respectively. The lua subdir of the mpv
    config dir is also now expected to be called scripts instead.
  * (!) The --fixed-vo option has been removed. It has been the default for
    a long time anyway, and disabling fixed-vo is not useful.
  * vo_opengl_hq has been updated to take into account new features.
    fancy-downscaling and sigmoid-upscaling are enabled, "mitchell" is now
    the default for scale-down.
  * The sub-visibility OSD message is now clearer about whether subtitles are
    hidden or just not available / selected.
  * The device IDs given to --audio-device for use with ao_coreaudio now use
    UIDs, so they don't change when devices are added/removed or after reboots.
  * --msg-level now also accepts ',' as separator.
  * (Client API) The client API now refuses to initialize if the LC_NUMERIC
    locale is not "C".
  * (Client API) The native type of the msg-level parameter is now a key-value
    list. Setting or reading it as a string still works.
  * (Slave API) The get_property command is now deprecated.
  * Documentation updates.
  * PDF documentation is now disabled by default due to rst2pdf being fickle,
    causing weird build errors.
  * Print desync messages with negative A/V sync as well. While rare, it could
    happen with some uses of --autosync.
  Bug fixes
  * (Windows) Avoid resizing the video window when player is minimized, might
    address bug #1547.
  * (NetBSD) Fix build with v4l2.
  * (Linux) Attempt to address conflicts with the pulseaudio mixer. (bug #1578)
  * Multiple cdda:// fixes. (bugs #1555, #1560)
  * VP9 timestamps no longer cause "missing PTS" warnings with new enough
    FFmpeg builds.
  * Fix a crash when using H.264 hardware decoding on new enough libavcodecs.
    (bug #1587)
  New features
  * vo_opengl now supports frame blending to eliminate stuttering when the video
    framerate does not nicely match the display framerate through the smoothmotion
    suboption. This is not meant to artificially increase the video's FPS, so
    there is no "soap opera effect" or difficulties with some video types
    (e.g. anime).
  * vo_opengl now supports sigmoidal upscaling (e.g. for fullscreen), which
    reduces ringing induced by upscaling, enabled through the sigmoid-upscaling
    suboption.
  * vo_opengl now supports ewa_lanczos (Jinc) scaling, which provides higher
    quality with less aliasing. It supports an experimental scale-antiringing
    parameter, which tries to further reduce video ringing.
  * vo_opengl now has a linear-scaling suboption, that makes the scalers work in
    linear light. Implied by the srgb, icc-profile or the new sigmoid-upscaling
    suboption.
  * vo_opengl has improved downscaling for higher downscale ratios when
    fancy-downscaling is enabled.
  * Add --keep-open=always to make --keep-open apply to all files instead of
    only the last.
  * mpv now filters the tags that are printed on the console to try to hide
    useless metadata. The filter works as a whitelist, and can be configured with
    the --display-tags option.
  * Add a --sub-scale-by-window option that, when set to 'no', prevents subtitles
    from changing their pixel size when the window changes sizes.
  * vo_opengl now technically has GLES 2 and 3 support (but not GLES 1). GLES 3
    support is only tested on Mesa's software emulation. GLES 2 has been tested on
    nvidia drivers. Both GLES modes are feature deficient and inefficient due to
    GLES limitations, so they should not be preferred over the standard OpenGL mode.
  * (X11) vo_opengl now supports the icc-profile-auto option on X11 hosts.
  * The 'A' key now by default cycles through a list of preset aspect ratios. Meant
    to be used to work around broken files.
  * There is now a "force" mode for --loop. Works like "inf", but tries to open
    files/streams even if there was an error on the previous attempt.
  * There is now a --log-file option to write mpv's log messages to a specifed file.
  * There is now a --audio-file-auto option to automatically load an external audio
    file with certain constraints. Will only load external audio if the playing
    file has a video stream. Set to "exact" by default. (bug #967)
  * There is now a --network-timeout option to specify a timeout in seconds for
    network access. If 0 (default), uses the libavformat default. If a protocol
    that doesn't support timeouts is used, this option is ignored.
  * (X11) The XF86 special keys are now all mappable in input.conf. All keys
    documented in XF86keysym.h are available, but only as their numeric codes.
  * (Linux) The DVB implementation now supports DVB-S2 through S2API.
  * (Linux) The VDR format for channels.conf is now supported and preferred.
    See http://linuxtv.org/vdrwiki/index.php/Syntax_of_channels.conf for the
    syntax. Tuning to DVB-S2 channels requires the VDR-format channels.conf.
  * (Linux) There is now a --dvbin-full-transponder option for handling special
    broadcast cases where PIDs switch, or just to work around incomplete PID data.
  * (Client API) There is now an opengl_cb VO, which receives the OpenGL context
    from the libmpv client. This allows a client to render libmpv video directly
    to a provided OpenGL context without having to use --wid embedding.
  * (Client API) The aforementioned --wid parameter can now be set at any time,
    but has no effect if a file is already loaded.
  * (Client API) The list of DVD titles can now be queried.
  * (Client API) There is now a filtered-metadata property, containing only the
    tags allowed by --display-tags.
  * (Client API) There is now support for XEmbed --wid targets, such as a
    GtkSocket's gtk_socket_get_id().
  * (Client API) There is now a file-format property with a symbolic name for the
    file format. In some cases this might be a comma separated list of various
    different extensions due to libavformat idiosyncrasies.
  * (Client API) There is now a mouse command for generating mouse events over
    the video window.
  * (Client API) There is now a partially-seekable property that indicates whether
    a file is only considered seekable because of the stream cache, but would not
    be seekable otherwise (e.g. realtime stream, or HTTP with no resume support).
    Small relative seeks may be fine, but larger seeks will likely fail.
  * (Client API) There is now an MPV_EVENT_QUEUE_OVERFLOW event that is posted
    whenever events have to be dropped because the queue is full. No further
    events are posted until the MPV_EVENT_QUEUE_OVERFLOW is consumed to avoid
    duplicated posting.
  * (Client API) There is now a helper mpv_wait_async_requests() function that
    blocks until all known async requests have completed. (bug #1542)
  * (Client API) There is now a detected-hwdec property that returns the detected
    hardware decoder when one is successfully opened. This probably only returns
    a valid value after playback has started.
  * (Client API) There are now audio_add, audio_remove and audio_reload
    counterparts to the equivalent sub_ commands for handling external audio
    files.
* Fri Jan 30 2015 scarabeus@opensuse.org
- Add BSD-3-Clause license as it is what waf is under
* Thu Jan 29 2015 aloisio@gmx.com
- Version bump to 0.7.3:
  Changes
  * Several documentation updates and typo fixes.
  * Don't show "0%%" position when the stream is infinite / has
    unknown length.
  * Fixes the config file loading order so that lower priority
    `mpv.conf` files don't override higher priority `config` files.
  * The subtitle decoder now gets reset when cycling subtitles.
    This makes the currently shown subtitle event disappear even if
    cycling back to the current subtitle track.
  * `--shuffle` and `--merge-files` now affects the contents of
    playlist files, instead of just the list of files given as
    arguments to mpv.
  * (Linux) `ao_alsa` now deals better with audio device
    disconnection.
  Bug fixes
  * Fixes for handling mono audio on various AOs.
  * (Linux) Fixes resuming from suspend on ao_alsa.
  * Fixes for playlist file parsing.
  * Fix rendering resolution of certain DVB subtitles (bug #1425).
  * Fix EDL or --merge-files breaking timestamps with .avi files.
  * Workaround for libavcodec bug with the VP9 codec parser
    (bug #1448), fixes possible crash.
  * Improve robustness of the matroska parser with broken files
    (bugs #1457, #1461).
  * Improve 10bit video compatibility with older GPUs (specially Intel)
    (bug #1383).
  * Fixes flashing the VO window when playing a list of files that
    includes non-media files (bug #1459).
  * Workaround for window embedding in OpenBox (bug #1235)
  * Fixes for several crashes and lockups (bugs #838, #1389, #1408,
    [#1463], #1473, #1474).
  * Fixes for the zsh completion script (bugs #997)
  New features
  * mpv now prints the contents of its config.h when running in
    verbose mode, to aid with debugging.
  * The `include=` option now accepts `~` to refer to the HOME dir
    (bug #1406).
  * `af_volume` now prints ReplayGain values in verbose mode.
  * m3u playlists that don't have the `#EXTM3U` header are now
    accepted if they "look like" ASCII or UTF-8 text and have the
    .m3u extension.
  * Chapter marks in the seek bar now update when switching files.
  * Supports embedded cover art in MKV files (bug #1374).
  * (Linux) vo_wayland now supports key modifiers (Meta, Alt,
    Control, Shift)
* Thu Dec 25 2014 scarabeus@opensuse.org
- Version bump to 0.7.2:
  * update waf to 0.8.5
  * Give precedence to the DVD menu navigation keyboard bindings so that user
    defined LEFT/RIGHT/... bindings don't break DVD menu navigation.
  * Try to fallback to the "default" device if the selected device is busy in
    the alsa AO.
  * Restore ab-loop settings with playback resume.
  * Don't signal an error if --stream-dump is used.
  * Fix removing key bindings from Lua scripts.
  * Reject channel descriptions with too many channels in the coreaudio AO.
  * Don't async redraw when waiting for VO redraw on OS X (this fixes the very
    annoying glitch where the black bars disappear for a single frame when
    going fullscreen).
  * Fix mono playback with the also AO.
  * Don't crash if framebuffers are not available in the opengl VO.
* Sat Dec 20 2014 seife+obs@b1-systems.com
- fix the UNKNOWN replacement :-)
* Tue Dec 16 2014 scarabeus@opensuse.org
- Replace the UNKNOWN in --version with date from changelog
* Sun Dec 14 2014 scarabeus@opensuse.org
- Quvi was dropped so remove it from the deps
* Fri Dec  5 2014 scarabeus@opensuse.org
- Version bump to 0.7.1:
  * Don't show the volume neutral marker on the OSD if softvol is disabled.
  * Don't select a subtitle track when executing the sub_add input command in "auto" mode.
  * Fix busy loop when seeking while paused (this fixes a problem with pulseaudio that caused mpv and the pulseaudio daemon to use 100%% CPU).
  * Fix Lua function utils.subprocess() in Windows versions older than Vista.
  * Avoid creating a window bigger than the screen on Windows.
  * Don't ignore the last line in m3u playlists.
  * Don't crash if a codec could not be opened.
  * Dynamically allocate audio channel map entries (this should fix a crash in the alsa and coreaudio AOs with audio devices that support more than 20 channel maps).
  * Ignore the "srgb" option in the opengl VO if hardware decoding is enabled.
  * Linearize non-RGB sRGB files correctly (eg. JPEG).
  * Fix opening reference URLs (.file/id=) on OS X.
  * Buffer partial log messages in the client API (the client API will now only pass full log messages to clients).
  * Remove ncurses/terminfo/termcap support (it was disabled by default and replaced by new code since v0.6.0).
  * Enable cdda:// support by default again (it was disabled since v0.6.0).
  * Cascade-load input.conf (if there are several input.confs in the set of valid config paths, load them all).
  * Draw the OSD twice in 3D mode (this fixes subtitles display in 3D mode).
  * Make wasapi the default AO on Windows again since many of its problems have been solved.
  * Use "site-functions" subdir to install the zsh completion script instead of the Debian-specific "vendor-completions" (also provide the --zshdir waf configure option for changing this value).
  * Improve synchronization between the Cocoa GUI and the player (this fixes some long standing deadlock issues on Mac OS X).
  * Remove --fs-missioncontrol option (only relevant to Mac OS X).
  * Enable pitch correction by default when playing at higher speeds (this can be controlled with the --audio-pitch-correction option).
  * Open stream and demuxer asynchronously (this should avoid having the player get blocked on network streams).
  * Add cache-buffering-state property for querying the cache fill status until the player unpauses.
  * Add support for listing and selecting the audio device (note that it is not implemented for all AOs, see the --audio-device option for more information).
  * Add support for a JSON-based IPC mechanism (note that this is not currently supported on Windows, see the JSON IPC section in the manpage for more information).
  * Add Lua utility function for starting processes (see utils.subprocess() in the manpage).
  * Add Lua utility function for parsing JSON (see utils.parse_json() in the manpage).
  * Add field-dominance property (see --field-dominance option).
  * Add video-rotate property (see --video-rotate option).
  * Add playback-abort property for querying whether playback is stopped or is to be stopped.
  * Add cursor-autohide property (see --cursor-autohide option).
  * Add vo-configured property for querying whether a window is created.
  * Add support for dxva2 hardware acceleration on Windows.
  * Drop libquvi support (this has been replaced by a built-in Lua script that invokes the youtube-dl tool, which needs to be installed, see the --ytdl option).
  * Add support for loading chapters from an external file (see the --chapters-file option).
  * Add window-minimized property for querying whether the window is minimized (works for X11 only).
  * Make it possible to configure the OSC seekbar style (see the "seekbarstyle" OSC option).
  * Add support for libmpv on Mac OS X (it used to be broken, now it's fully functional and also provides support for embedding the mpv window inside a Cocoa/Qt application).
  * Try to use the audio channel map reported by ALSA in the alsa AO.
  * Add option to disable text OSD rendering completely (useful for working around certain fontconfig issues, see the --use-text-osd option).
* Mon Nov 24 2014 scarabeus@opensuse.org
- Add --enable-libmpv-shared to build shared library.
* Mon Nov 24 2014 scarabeus@opensuse.org
- Revert back to support wayland.
* Fri Nov 21 2014 scarabeus@opensuse.org
- Blacklist the wayland as it for some reason now have trouble properly
  linking resulting in unresolvable package
* Mon Oct 27 2014 scarabeus@opensuse.org
- Version bump to 0.6.2:
  * The --ass-style-override option now requires a newer version of libass.
  * Correctly signal EOF when using --frames.
  * Strictly endorce the limit imposed by --frames (i.e. avoid producing an extra frame at the end).
  * Fix \x-style escaping when parsing commands.
  * Correctly handle ^h key on the terminal (this should fix the when inserted from Backspace key on new versions of xterm).
  * Don't put the player to sleep after audio reinit.
  * Properly exit if both audio and video fail to initialize.
* Thu Oct 16 2014 scarabeus@opensuse.org
- Version bump to 0.6.1:
  * Don't show message on "osd" command by default (this essentially reverts a change introduced in the last release).
  * Add an alternative input configuration that reverts the key binding changes introduced by previous releases (see etc/restore-old-bindings.conf in the sources).
  * Automatically install example input configuration files.
  * Fix stream languages with Bluray
  * Don't try to create surfaces of size 0 in the VDPAU vo.
  * Don't print audio/video init failure message twice.
  * Fix playback on the root window on X11 (i.e. when using --wid=0).
  * Fix the autodetection of the input format in the vf_stereo3d filter when mpv is built against libav (this makes --video-stereo-mode work with libav as well).
  * Fix compilation with PulseAudio 1.0.
  * Fix compilation with clang.
  * Try harder to decode cover art picture only once.
  * Fix cursor autohide (--cursor-autohide) with audio-only files on file change (e.g. when skipping to the next playlist file).
* Wed Oct  1 2014 aloisio@gmx.com
- Version bump to 0.6.0
  * Numerous changes and new features, see official changelog
* Thu Sep 11 2014 scarabeus@opensuse.org
- Version bump to 0.5.3:
  * Do not honor XDG_CONFIG_DIRS to always read global configs
  * Fix speed behaviour changes
  * Seeking fixes
  * Handle EOF better
* Fri Aug 29 2014 scarabeus@opensuse.org
- Version bump to 0.5.1:
  * Various changes with major release
  * Also look in XDG folders for config
  * Default config renamed to mpv.conf
* Mon Aug  4 2014 scarabeus@opensuse.org
- Version bump to 0.4.2:
  * Fix --cache-file operation when file size is unknown (e.g. when playing from a pipe).
  * Don't sleep if playback is stopped when reconnecting for remote stream.
  * Suspend read on vts change even if the requested title is not found when using dvdnav (dvd://) (this fixes a bug where the DVD menu was not shown properly after a DVD track ended).
  * Avoid draining if the audio output is paused (this fixes a bug where mpv would hang when switching tracks when paused).
  * Drop buffered audio when switching tracks or filters (this fixes a possible regression when using gapless audio).
  * Reverse video rotation direction.
  * Fix initialization of the input when playing from a pipe.
  * Fix description of the --mf option in the manpage (the --mf syntax changed a while ago, but was not documented).
  * Actually append entries to the end of the playlist instead of after the current entry with the "loadlist append" command.
* Sun Jul 13 2014 scarabeus@opensuse.org
- Version bump to 0.4.1:
  * Various small bugfixes
* Tue Jul  1 2014 scarabeus@opensuse.org
- Version bump to 0.4.0:
  * Manpages generating now uses only rst2...
  * Enforce enabling cdda
  * Update requirement for new waf tarball
  + Use dvdnav for dvd:// parsing
  + Various cli arguments changed name see --help for changes
  + Removed radio support
  + For more read https://github.com/mpv-player/mpv/releases/tag/v0.4.0
* Mon Jun 23 2014 scarabeus@opensuse.org
- Version bump to 0.3.11:
  * Small fixes
  * Fix to build with latest git ffmpeg
* Mon May 26 2014 scarabeus@opensuse.org
- Version bump to 0.3.10
  * Various small fixes.
* Wed Apr 30 2014 scarabeus@opensuse.org
- Version bump to 0.3.9:
  * Various small fixes.
* Sun Apr 20 2014 scarabeus@opensuse.org
- Version bump to 0.3.8:
  * Bugfixes around vo=vdpau mostly
* Mon Mar 31 2014 scarabeus@opensuse.org
- Version bump to 0.3.7:
  * Small bugfixes especially around old ffmpeg/libav versions.
* Wed Mar 12 2014 scarabeus@opensuse.org
- Version bumjp to 0.3.6:
  * Various minor bug fixes.
* Sun Feb 16 2014 scarabeus@opensuse.org
- Version bump to 0.3.5:
  * use the c99 to avoid few issues
  * fixes in vo_opengl output
* Tue Feb  4 2014 scarabeus@opensuse.org
- Version bump to 0.3.4:
  * bugfixes all around
  * disabled quvi 0.9 subtitles as they were too broken
* Thu Jan 16 2014 scarabeus@opensuse.org
- Version bump to 0.3.3:
  * Fixes matroska containers
  * Wayland fixes
* Wed Jan  8 2014 scarabeus@opensuse.org
- Version bump to 0.3.2:
  * Fix regression with autoenabling subtitles with quvi
  * Various unspecified bugfixes
* Mon Jan  6 2014 scarabeus@opensuse.org
- Version bump to 0.3.1, fixing few issues.
* Thu Jan  2 2014 scarabeus@opensuse.org
- Drop support for < 12.3 as even 12.2 will be out of scope in 13
  days.
* Mon Dec 30 2013 scarabeus@opensuse.org
- Enable libv4l.
* Mon Dec 30 2013 scarabeus@opensuse.org
- Version bump to 0.3.0:
  * Feature update in various areas, notably support for dvdnav
  * Build system was rewritten under waf
  * Multiple subtitles can be now displayed at once
  * vdpau/vaapi acceleration can be used with opengl output
- Run .desktop file updaters
* Sun Dec  8 2013 scarabeus@opensuse.org
- Version bump to 0.2.4:
  * Audio fixes
  * Small bugfixes
* Sat Nov 23 2013 scarabeus@opensuse.org
- Reduce pkgconfig deps where it seems proper.
* Sat Nov 23 2013 scarabeus@opensuse.org
- Fix docu generating and add luajit dependency.
- Try to convert the deps to pkgconfig syntax.
* Sat Nov  9 2013 scarabeus@opensuse.org
- Verison bump to 0.2.3:
  * Handle more signals
  * Fix audio detection with some formats
  * More tiny fixes
* Wed Nov  6 2013 scarabeus@opensuse.org
- Version bump to 0.2.2:
  * Tiny bugfixes
- Depend on rst2tex when available, still broken configure check
  to be fixed next time.
* Mon Oct 21 2013 scarabeus@opensuse.org
- Version bump to 0.2.1:
  * Various small fixes
- Fix build with samba again, fixed in git properly for next
  release.
* Thu Oct 17 2013 scarabeus@opensuse.org
- Fix directory ownership on icondirs.
* Thu Oct 17 2013 scarabeus@opensuse.org
- Version bump to 0.2.0:
  * new icon
  * Add an On Screen Controller (OSC)
  * Subtitles: make automatic charset detection the default
  * More intuitive chapter seeking behavior
  * support for VA-API hardware decoding and display
  * Preliminary Lua scripting support
  * Switch to GPL version 2 or later for mpv as a whole
* Tue Sep 24 2013 scarabeus@opensuse.org
- Install configuration examples for users to inspire themselves.
* Mon Sep 23 2013 scarabeus@opensuse.org
- Version bump to 0.1.7:
  * manpage fixes
  * mkv subtitle fixes
  * various bugfixes
* Mon Sep 16 2013 scarabeus@opensuse.org
- Make mpv build on 12.2 too, what a release.
* Mon Sep 16 2013 scarabeus@opensuse.org
- Disable jack on 11.4 so the package actually builds.
* Mon Sep 16 2013 scarabeus@opensuse.org
- And make 11.4 happy too wrt dep resolution.
* Mon Sep 16 2013 scarabeus@opensuse.org
- Make this work with older releases too (versioned ifs for deps).
* Sun Sep 15 2013 scarabeus@opensuse.org
- Update license and ship readme.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Fix description.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Fix dep on python3-docutils as they are borked now, use py2 for
  time being, told sachpe to figure it out.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Sort out remaining dependencies so we can build.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Initial spec file for mpv media player.
  * Based from mplayer2 spec.
